@@ -15,6 +15,7 @@
 #
 # Copyright (c) 2017 by Delphix. All rights reserved.
 # Copyright (c) 2018 by Lawrence Livermore National Security, LLC.
+# Copyright (c) 2025, Klara, Inc.
 #
 # This script must remain compatible with Python 3.6+.
 #
@@ -231,7 +232,7 @@ maybe = {
     'cli_root/zpool_trim/zpool_trim_fault_export_import_online':
         ['FAIL', known_reason],
     'cli_root/zpool_upgrade/zpool_upgrade_004_pos': ['FAIL', 6141],
-    'cli_user/misc/arc_summary_001_pos': ['FAIL', known_reason],
+    'cli_user/misc/zarcsummary_001_pos': ['FAIL', known_reason],
     'delegate/setup': ['SKIP', exec_reason],
     'events/zed_cksum_config': ['FAIL', known_reason],
     'fault/auto_replace_002_pos': ['FAIL', known_reason],
@@ -381,7 +382,8 @@ def process_results(pathname):
 
     prefix = '/zfs-tests/tests/(?:functional|perf/regression)/'
     pattern = \
-        r'^Test(?:\s+\(\S+\))?:' + \
+        r'^(?:\[[0-9\-T:\.]+\]\s+)?' + \
+        r'Test(?:\s+\(\S+\))?:' + \
         rf'\s*\S*{prefix}(\S+)' + \
         r'\s*\(run as (\S+)\)\s*\[(\S+)\]\s*\[(\S+)\]'
     pattern_log = r'^\s*Log directory:\s*(\S*)'
